context("canvasXpress Web Charts - RidgeLine")


test_that("cXridgeline1", {
    check_ui_test(cXridgeline1())
})

test_that("cXridgeline2", {
    check_ui_test(cXridgeline2())
})

test_that("cXridgeline3", {
    check_ui_test(cXridgeline3())
})

test_that("cXridgeline4", {
    check_ui_test(cXridgeline4())
})

test_that("cXridgeline5", {
    check_ui_test(cXridgeline5())
})

test_that("cXridgeline6", {
    check_ui_test(cXridgeline6())
})

test_that("cXridgeline7", {
    check_ui_test(cXridgeline7())
})
